@@ -15,8 +15,8 @@ session = queries.Session(
         os.environ.get('PGDATABASE'),
         os.environ.get('PGUSER'),
         os.environ.get('PGPASSWORD'),
-    ) + ('?application_name=' +
-         os.environ.get('PGAPPNAME')) if os.environ.get('PGAPPNAME') else '')
+    ) + (('?application_name=' +
+          os.environ.get('PGAPPNAME')) if os.environ.get('PGAPPNAME') else ''))
 
 print("Database connected")
 
